<?php

include 'sdk/AvisAuthentiques.php';

use sdk\AvisAuthentiques as ClientAvisAuthentiques;

class AvisAuthentiques
{
    const API_HOST = 'host.docker.internal';
    const API_PORT = 8443;

    private static $initiated = false;

    public static function init()
    {
        if (!self::$initiated) {
            self::init_hooks();
        }
    }

    /**
     * Initializes WordPress hooks
     */
    private static function init_hooks()
    {
        self::$initiated = true;
        add_action('wp_footer', array('AvisAuthentiques', 'displayWidget'));
//        add_action('woocommerce_payment_complete', array('AvisAuthentiques', 'paymentCompleted'));
        add_action('woocommerce_order_status_completed', array('AvisAuthentiques', 'paymentCompleted'));
    }

    /**
     * Attached to activate_{ plugin_basename( __FILES__ ) } by register_activation_hook()
     * @static
     */
    public static function plugin_activation() {
        if ( version_compare( $GLOBALS['wp_version'], AVIS_AUTHENTIQUES__MINIMUM_WP_VERSION, '<' ) ) {
            load_plugin_textdomain( 'avis-authentiques' );

            $message = '<strong>'.sprintf(esc_html__( 'Avis-Authentiques %s requires WordPress %s or higher.' , 'avis-authentiques'), AVIS_AUTHENTIQUES_VERSION, AVIS_AUTHENTIQUES__MINIMUM_WP_VERSION ).'</strong> '.sprintf(__('Please <a href="%1$s">upgrade WordPress</a> to a current version.', 'avis-authentiques'), 'https://codex.wordpress.org/Upgrading_WordPress', 'https://wordpress.org/extend/plugins/akismet/download/');

            AvisAuthentiques::bail_on_activation( $message );
        } elseif ( ! empty( $_SERVER['SCRIPT_NAME'] ) && false !== strpos( $_SERVER['SCRIPT_NAME'], '/wp-admin/plugins.php' ) ) {
            add_option( 'Activated_Avis_Authentiques', true );
        }
    }

    private static function bail_on_activation( $message, $deactivate = true ) {
        ?>
        <!doctype html>
        <html>
        <head>
            <meta charset="<?php bloginfo( 'charset' ); ?>" />
            <style>
                * {
                    text-align: center;
                    margin: 0;
                    padding: 0;
                    font-family: "Lucida Grande",Verdana,Arial,"Bitstream Vera Sans",sans-serif;
                }
                p {
                    margin-top: 1em;
                    font-size: 18px;
                }
            </style>
        </head>
        <body>
        <p><?php echo esc_html( $message ); ?></p>
        </body>
        </html>
        <?php
        if ( $deactivate ) {
            $plugins = get_option( 'active_plugins' );
            $avisAuthentiques = plugin_basename( AVIS_AUTHENTIQUES__PLUGIN_DIR . 'avis-authentiques.php' );
            $update  = false;
            foreach ( $plugins as $i => $plugin ) {
                if ( $plugin === $avisAuthentiques ) {
                    $plugins[$i] = false;
                    $update = true;
                }
            }

            if ( $update ) {
                update_option( 'active_plugins', array_filter( $plugins ) );
            }
        }
        exit;
    }

    public static function displayWidget()
    {
        echo '<review-widget widget-key="'. get_option('avis_authentiques_widget_key') .'" position="'. get_option('avis_authentiques_position') .'" />';
        wp_enqueue_script('avis-authentiques', plugins_url('/js/front.js', __FILE__));
    }

    public static function paymentCompleted($orderId)
    {
        $order = wc_get_order( $orderId );

        $env = wp_get_environment_type();

        $avisAuthentiques = new ClientAvisAuthentiques(get_option('avis_authentiques_api_key'), $env !== 'production');

        $avisAuthentiques->addOrder((string)$order->get_id(), $order->get_billing_email(), $order->get_billing_last_name(), $order->get_billing_first_name());

    }
}